@@ -1,3 +1,8 @@
+#![deny(rustdoc::missing_crate_level_docs)]
+#![deny(missing_docs)]
+#![deny(missing_debug_implementations)]
+#![doc = include_str ! ("../Readme.md")]
+
 mod methods;
 mod traits;
 
