@@ -14,9 +14,7 @@ where
             (Unset, Initial) => Unset,
             (Unset, Unset) => Unset,
             (Unset, Normal(rhs)) => Normal(rhs),
-            (Normal(_), Initial) => {
-                return;
-            }
+            (Normal(_), Initial) => return,
             (Normal(_), Unset) => Unset,
             (Normal(_), Normal(rhs)) => Normal(rhs),
         }
